#!/bin/bash

OLD_SERVER=$1
NEW_SERVER=$2

function switch_remote
{
	REPO_URL=`git remote -v | grep -m1 '^origin' | grep -m1 "$OLD_SERVER" | sed -Ene's#.*(git@[^[:space:]]*).*#\1#p'`
	if [ -z "$REPO_URL" ]; then
	  REPO_URL=`git remote -v | grep -m1 '^origin' | grep -m1 "$NEW_SERVER" | sed -Ene's#.*(git@[^[:space:]]*).*#\1#p'`
	  if [ -z "$REPO_URL" ]; then
	    echo "-- Could not identify Repo URL. Skipping."
	    echo "-- directory: $PWD"
	    echo ""
	    return 0
	  else
	    echo "   This repository already seems to use the new remote URL. Skipping."
	    echo "-- directory: $PWD"
	    echo ""
	    return 0
	  fi
	fi

	GROUP=`echo $REPO_URL | sed -e's/.git$//' -Ene"s#git@$OLD_SERVER:([^:]*)/(.*)#\1#p"`
	if [ -z "$GROUP" ]; then
	  echo "-- ERROR:  Could not identify Group."
	  exit
	fi

	REPO=`echo $REPO_URL | sed -e's/.git$//' -Ene"s#git@$OLD_SERVER:([^:]*)/(.*)#\2#p"`
	if [ -z "$REPO" ]; then
	  echo "-- ERROR:  Could not identify Repo."
	  exit
	fi

	NEW_URL="git@$NEW_SERVER:$GROUP/$REPO.git"
	echo "Changing repo URL from "
	echo "  '$REPO_URL'"
	echo "      to "
	echo "  '$NEW_URL'"
	echo ""

	CHANGE_CMD="git remote set-url origin $NEW_URL"
	`$CHANGE_CMD`
}

if [ "$OLD_SERVER" == "" ] || [ "$NEW_SERVER" == "" ]; then
	echo "Usage:    change-remote.sh <old-server-root> <new-server-root>"
	echo "Example:  change-remote.sh git.domain1.de git.domain2.de"
	exit
fi

dir=${PWD##*/}
if [ "$dir" != "yocto-exceet" ]; then
	echo "-- ERROR:  Please run this in the yocto-exceet directory!"
	exit
fi

switch_remote

for build in ` find build* -maxdepth 0 -mindepth 0 -type d`
do
	cd "$build"
	switch_remote
	cd ".."
done

for meta in `find layers -maxdepth 1 -mindepth 1 -type d`
do
	cd "$meta"
	switch_remote
	cd "../.."
done

echo "Success"
